==> xmpp-extensions-common-0.8.0-sources.jar: rocks/xmpp/extensions/pubsub/model/errors/ConfigurationRequired.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2016 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.extensions.pubsub.model.errors;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

/**
 * The implementation of the {@code <configuration-required/>} pubsub error.
 * This class is a singleton.
 *
 * @author Christian Schudt
 * @see #CONFIGURATION_REQUIRED
 * @see <a href="https://xmpp.org/extensions/xep-0060.html#subscriber-subscribe-configure">6.1.5 Configuration Required</a>
 */
@XmlRootElement(name = "configuration-required")
@XmlType(factoryMethod = "create")
public final class ConfigurationRequired extends PubSubError {
    ConfigurationRequired() {
    }

    private static ConfigurationRequired create() {
        return CONFIGURATION_REQUIRED;
    }
}

==> xmpp-extensions-common-0.9.0-sources.jar: rocks/xmpp/extensions/pubsub/model/errors/ConfigurationRequired.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2019 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.extensions.pubsub.model.errors;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

/**
 * The implementation of the {@code <configuration-required/>} pubsub error. This class is a singleton.
 *
 * @author Christian Schudt
 * @see #CONFIGURATION_REQUIRED
 * @see <a href="https://xmpp.org/extensions/xep-0060.html#subscriber-subscribe-configure">6.1.5 Configuration
 * Required</a>
 */
@XmlRootElement(name = "configuration-required")
@XmlType(factoryMethod = "create")
public final class ConfigurationRequired extends PubSubError {

    ConfigurationRequired() {
    }

    @SuppressWarnings("unused")
    private static ConfigurationRequired create() {
        return CONFIGURATION_REQUIRED;
    }
}
